from pristine_lfs import do_list


def test_pristine_lfs_list(test_git_repo, capsys):
    do_list(branch='pristine-lfs')
    captured = capsys.readouterr()
    assert test_git_repo.tarball.name == captured.out.strip('\n'), 'Expected tarball not found'

    do_list(branch='debian/test')
    captured = capsys.readouterr()
    assert "debian/changelog" == captured.out.strip('\n'), 'This branch should only have the changelog'



from pristine_lfs import do_checkout


def test_pristine_lfs_simple_checkout(fake_pristine_lfs):
    repo, tarball, size, sha = fake_pristine_lfs
    outdir = repo / 'tmp'

    do_checkout('pristine-lfs', tarball=tarball.name, outdir=outdir)
    assert len(list(outdir.glob('**'))) == 1, list(outdir.glob('**'))
    assert (outdir / tarball.name).is_file()
    assert (outdir / tarball.name).stat().st_size == size


def test_pristine_lfs_auto_checkout(test_git_repo):
    repo, tarball, size, sha = test_git_repo
    outdir = repo / 'tmp-explicit'

    do_checkout('pristine-lfs', tarball=tarball.name, outdir=outdir)
    assert len(list(outdir.glob('**'))) == 1, list(outdir.glob('**'))
    assert (outdir / tarball.name).is_file()
    assert (outdir / tarball.name).stat().st_size == size

    outdir = repo / 'tmp-auto'

    do_checkout('pristine-lfs', tarball=None, outdir=outdir)
    assert len(list(outdir.glob('**'))) == 1, list(outdir.glob('**'))
    assert (outdir / tarball.name).is_file()
    assert (outdir / tarball.name).stat().st_size == size





from textwrap import dedent

from sh.contrib import git

from pristine_lfs import do_commit


def test_pristine_lfs_commit(fake_tarball):
    repo, tarball, size, sha = fake_tarball

    do_commit(tarball.open('rb'), branch='pristine-lfs')
    do_commit(tarball.open('rb'), branch='pristine-lfs', message='blip %s %s %s')
    do_commit(tarball.open('rb'), branch='pristine-lfs', message='blip')

    # verify the file has indeed been committed
    commit = git('rev-parse', 'pristine-lfs^{tree}').strip('\n')
    pointer = git('cat-file', 'blob', f"{commit}:{tarball.name}")
    assert pointer == dedent(
        f"""
        version https://git-lfs.github.com/spec/v1
        oid sha256:{sha}
        size {size}
        """).lstrip('\n'), 'Object pointer doesn’t match the object'

    stored = repo / '.git' / 'lfs' / 'objects' / sha[:2] / sha[2:4] / sha
    assert stored.is_file(), 'Object has not been stored by LFS'
